# unitorch.cli.models.deberta

## DebertaProcessor

!!! tip
    **`core/process/deberta`** is the section for configuration of DebertaProcessor.

::: unitorch.cli.models.deberta.DebertaProcessor

## DebertaForClassification

!!! tip
    **`core/model/classification/deberta`** is the section for configuration of DebertaForClassification.

::: unitorch.cli.models.deberta.DebertaForClassification

## DebertaV2Processor

!!! tip
    **`core/process/deberta/v2`** is the section for configuration of DebertaV2Processor.

::: unitorch.cli.models.deberta.DebertaV2Processor

## DebertaV2ForClassification

!!! tip
    **`core/model/classification/deberta/v2`** is the section for configuration of DebertaV2ForClassification.

::: unitorch.cli.models.deberta.DebertaV2ForClassification

